package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````T!D!`#0```!HD0````0`!30`(``)
M`"@`'``;``$``'`T@P``-(,!`#2#`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0!`@P``0(,```4```````$`
M`0```+R-``"\C0(`O(T"`%0"``"`$@``!@```````0`"````W(T``-R-`@#<
MC0(`$`$``!`!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO(T`
M`+R-`@"\C0(`1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`8/]Y#AO%<[A[6)$+I^WZWWJ$GL<$
M````$`````$```!'3E4```````,````"`````````&$````$````(`````H`
M``"H$A```D01(``"0`!6`'`8P@@`,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@80"$"#Y"/)<``0`()%B`!(E@#)-X"4):0$0`0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(,`@!`D`D``D#I-&0`0`````
M````!0````8````(``````````````````````````D````+````#`````X`
M```/````$````!(````5`````````````````````````!<````:````&P``
M`!\````@````(0```"(`````````(P```"4````I`````````"L`````````
M`````"P````M````+@```"\`````````,P```#0````V````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$<`
M``!(````20```$H`````````2P``````````````````````````````````
M`$P```!-`````````$\`````````40```%,```!5````````````````````
M`````%8```!:````6P```%P`````````7@``````````````8```````````
M````8@```&0```!E````9@```&D```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<5K&IY0
MQ8D%D&&8[Q(!(_FD0OK7AYV[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#(.4`?,V+;[3^>
M0D3I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_
M+)@BU&BZXY)\(?_D#HJ8W<)O>FGZDZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;[S02WUW;^-P:@E#UI\BQZ@A8F0'?JF<FV+0^H+L
M+/:+:W^:?(?PEGP5C"7,[@M1^?/;TQV0=8(-0V9+$#RM.0T7ZEKQIIN3'*/@
M^TE7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````
M`!$``````````````"`````M```````````````@````/```````````````
M(````"(#`````````````!(````2`@`````````````2````D`(`````````
M````$@```&T"`````````````!(````9!````)`"```````@`!<`DP$`````
M````````$@```&8"`````````````!(```"#`0``"!4!```````2````G@,`
M`!"0`@``````$``8`"D"`````````````!(```!+`@`````````````2````
M600```R0`@`$````$0`7`-,"`````````````!(```#1!```D"\!`'0#```2
M``T`\P,``+@D`0```0``$@`-`"D#`````````````!(````Q`@``````````
M```2````Y`(`````````````$@```-L#```\H`(``````!``&`"^`P``````
M```````2````_P,``,0H`0#,!@``$@`-`#,$``"<(0$`S````!(`#0#F`P``
MD"0!`"@````2``T`6`(`````````````$@```"0"`````````````!(```!<
M`0`````````````2````P`(`````````````$@```'T$```P0P$`1`$``!(`
M#0`\`P``$)`"``0````A`!@`]P$`````````````$@```.`!````````````
M`!(````,!```\$$!`$`!```2``T`@@(`````````````$@```-,#```0D`(`
M`````!``%P"=`@`````````````2````<P```"07`0``````$@```&`"````
M`````````!(```#T`@`````````````2````\0$`````````````$@```-L!
M`````````````!(````]`P``$)`"``0````A`!@`:`0``#R@`@``````$``8
M`-T"```@D`(`!````!$`&`!]`P``U$0!``0````2``T`9P$`````````````
M$@```$,!`````````````!(```!)!```=$0!`&`````2``T`J`0``/0G`0#0
M````$@`-`#H"`````````````!(````=!```T!D!```````2``T`DP``````
M````````$@```)\``````````````!(```"R`@`````````````2````XP``
M`!B0`@`!````$0`8`'L"`````````````!(````D!```]$0!``0````1``\`
MAP0``!"0`@``````$``8`/L"`````````````!(````3`P`````````````2
M````5@``````````````$@```/```````````````!(```"3!```%"$!`#0`
M```2``T`#`$`````````````$@```&,$```\H`(``````!``&`";!```;"(!
M`"0"```2``T`M```````````````$@```$4#`````````````!(```#^`0``
M```````````2````=0$`````````````$@```,(``````````````!(```#4
M```````````````2`````0$``!20`@`$````$0`8`#L#```0D`(`!````!$`
M&``U`0`````````````2````B0(`````````````$@```-H#```\H`(`````
M`!``&`"Z!```6"<!`(0````2``T`A```````````````$@```,L"````````
M`````!(````7!````)`"```````0`!<`!0,`````````````$@```&L#``#$
MC0(`!````!$`%`"L`P``W"<!`!@````2``T`L0$`````````````$@```)X!
M`````````````!(````V`P``J!<!`"@"```2``T`$0$`````````````$@``
M`,@$``!D00$`C````!(`#0#K`@`````````````2````O`$``,B-`@`3````
M$0`4`*L"`````````````!(```"7`@`````````````2````J@$`````````
M````$@```!L#`````````````!(```!T`@`````````````2````<`0``+@E
M`0"@`0``$@`-`!8!`````````````!(```!2`@`````````````2````QP,`
M``0S`0!X````$@`-`&0``````````````!(```!3`0`````````````2````
MC0,``&@B`0`$````$@`-`"(!``"L%@$``````!(`````;&EB<&5R;"YS;RXU
M+C,P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M
M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?
M;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?
M9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`
M4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)P
M=&AR96%D+G-O+C``<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&]P96XV
M-`!P=&AR96%D7V=E='-P96-I9FEC`&QS965K-C0`;&EB8RYS;RXV`&5X:70`
M<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I
M<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S
M=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R
M:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M
M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L9"UL:6YU>"UA<FUH
M9BYS;RXS`%]?<W1A8VM?8VAK7V=U87)D`%]?;&EB8U]C<W5?9FEN:0!P87)?
M8W5R<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B
M87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?
M7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A
M<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?
M9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?
M:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT````````````
M``(``P`"``(``0````(````!``(``@`!``(``0`!``(``@`"``$``@`!``$`
M`0`"``(````"``$``@`#``,``0`"``$``@````(``@`#``,``@`!``(``0``
M`````0`!``(``0```````@````(``0`!``(``@```````0````$``0````(`
M`P````````````(````"``$``0````(``0`"``0``0```````0`"``$``@``
M``(``@`"``(``@`!`````@`!```````!`````0`!`%<#```0````(````!1I
M:0T```0`YP0````````!``$`RP$``!`````@````%&EI#0```P#G!```````
M``$``0`:`@``$``````````4:6D-```"`.<$````````_(\"`!4"``#$C0(`
M%%4``,B-`@`470``$)`"`!1,```4D`(`%$L``!B0`@`4.0``()`"`!0N``#X
MC@(`%@8``/R.`@`6!````(\"`!87```$CP(`%BL```B/`@`6%0``#(\"`!8^
M```0CP(`%EH``!2/`@`610``&(\"`!9>```<CP(`%@L``""/`@`67P``)(\"
M`!91```HCP(`%D(``"R/`@`6.```,(\"`!9B```TCP(`%C0``#B/`@`61@``
M/(\"`!8.``!`CP(`%AL``$2/`@`6,```2(\"`!9-``!,CP(`%EP``%"/`@`6
M20``5(\"`!97``!8CP(`%@4``%R/`@`66```8(\"`!92``!DCP(`%B$``&B/
M`@`68```;(\"`!83``!PCP(`%C$``'2/`@`6`@``>(\"`!8'``!\CP(`%AP`
M`("/`@`6)```A(\"`!9G``"(CP(`%BD``(R/`@`6-@``D(\"`!8B``"4CP(`
M%E0``)B/`@`6-P``G(\"`!8=``"@CP(`%F4``*2/`@`63@``J(\"`!9J``"L
MCP(`%C\``+"/`@`69```M(\"`!8)``"XCP(`%B8``+R/`@`60```P(\"`!8*
M``#$CP(`%F$``,B/`@`6.@``S(\"`!9(``#0CP(`%B<``-2/`@`6/0``V(\"
M`!9*``#<CP(`%F@``."/`@`6$```Y(\"`!8-``#HCP(`%B@``.R/`@`6*@``
M\(\"`!8>``#TCP(`%A0``/B/`@`61P``"$`MZ6$!`.L(@+WH!.`MY03@G^4.
MX(_@"/"^Y51Z`0``QH_B%\J,XE3ZO.4`QH_B%\J,XDSZO.4`QH_B%\J,XD3Z
MO.4`QH_B%\J,XCSZO.4`QH_B%\J,XC3ZO.4`QH_B%\J,XBSZO.4`QH_B%\J,
MXB3ZO.4`QH_B%\J,XASZO.4`QH_B%\J,XA3ZO.4`QH_B%\J,X@SZO.4`QH_B
M%\J,X@3ZO.4`QH_B%\J,XOSYO.4`QH_B%\J,XO3YO.4`QH_B%\J,XNSYO.4`
MQH_B%\J,XN3YO.4`QH_B%\J,XMSYO.4`QH_B%\J,XM3YO.4`QH_B%\J,XLSY
MO.4`QH_B%\J,XL3YO.4`QH_B%\J,XKSYO.4`QH_B%\J,XK3YO.4`QH_B%\J,
MXJSYO.4`QH_B%\J,XJ3YO.4`QH_B%\J,XISYO.4`QH_B%\J,XI3YO.4`QH_B
M%\J,XHSYO.4`QH_B%\J,XH3YO.4`QH_B%\J,XGSYO.4`QH_B%\J,XG3YO.4`
MQH_B%\J,XFSYO.4`QH_B%\J,XF3YO.4`QH_B%\J,XESYO.4`QH_B%\J,XE3Y
MO.4`QH_B%\J,XDSYO.4`QH_B%\J,XD3YO.4`QH_B%\J,XCSYO.4`QH_B%\J,
MXC3YO.4`QH_B%\J,XBSYO.4`QH_B%\J,XB3YO.4`QH_B%\J,XASYO.4`QH_B
M%\J,XA3YO.4`QH_B%\J,X@SYO.4`QH_B%\J,X@3YO.4`QH_B%\J,XOSXO.4`
MQH_B%\J,XO3XO.4`QH_B%\J,XNSXO.4`QH_B%\J,XN3XO.4`QH_B%\J,XMSX
MO.4`QH_B%\J,XM3XO.4`QH_B%\J,XLSXO.4`QH_B%\J,XL3XO.4`QH_B%\J,
MXKSXO.4`QH_B%\J,XK3XO.4`QH_B%\J,XJSXO.4`QH_B%\J,XJ3XO.4`QH_B
M%\J,XISXO.4`QH_B%\J,XI3XO.4`QH_B%\J,XHSXO.4`QH_B%\J,XH3XO.4`
MQH_B%\J,XGSXO.4`QH_B%\J,XG3XO.4`QH_B%\J,XFSXO.4`QH_B%\J,XF3X
MO.4`QH_B%\J,XESXO.4`QH_B%\J,XE3XO.4P0"WI)-!-XN`QG^44`(WE$!"-
MY0P@C>40$(WB#""-XA0`C>(`,)/E'#"-Y0`PH..8___KN"&?Y;@!G^4"$*#A
M.@L`Z[`QG^4`4-/E``!5XZA!GQ4)```::O__ZZ`AG^4``%#C$`""Y5T```J,
M09_E0/__ZP``E.7=___K<5?`Y0``E.7:___K`#"@X0``E.7&(]/E`B""X\8C
MP^74___K%#"=Y04P@^('`7/CQB/0Y0$@@N/&(\#E1@``B@,!H.%6___K$!"=
MY3C!G^4P09_E`#"1Y10@G>4$P)SE`0!2XP`P@.4@,9_E","`Y00P@.48P9_E
M!#"@XP0PA.4$,$'"#,"`Y0(Q@\`,P(#""`"$Y0,``-H$X+'E`0!3X03@K.7[
M__\:#<&"X@`0H.,`$(WE`#"@X0P1@.<#((+BT!"?Y1``E.5W___K`%!0XA$`
M``H0`)3E'___Z[@`G^48$(WB;```ZP``4.,.```*$`"4Y0/__^ME___K<#"?
MY0`@D^4<,)WE`B`SX!<``!H%`*#A)-"-XC"`O>@0`)3E?___ZP!0H.'I___J
M#`"4Y0``4.,!```*:`8`Z^O__^I8`)_E&!"-XE,``.L``%#C#`"$Y>7__PKV
M___J0!"?Y4``G^4[___K`0"@XR3__^OM_O_KS((!`*P6`0`D%P$`&)`"`!20
M`@`HD`(`")`"`"Q(`0`P2`$`2"$!`/1%`0"010$`R(T"`&A'`0``L*#C`."@
MXP00G>0-(*#A!"`MY00`+>40P)_E!,`MY0P`G^4,,)_E_O[_ZUK__^O41`$`
MJ!<!`'1$`0`4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P'Y_O_JT'0!`!`!```8
M`)_E&#"?Y0``4^$>_R\!$#"?Y0``4^,>_R\!$_\OX1"0`@`0D`(``````"0`
MG^4D$)_E`#!!X*,?H.%#$8'@P1"PX1[_+P$0,)_E``!3XQ[_+P$3_R_A$)`"
M`!"0`@``````$$`MZ1A`G^4`,-3E``!3XQ"`O1C@___K`3"@XP`PQ.40@+WH
M))`"`.;__^KP1RWI`)!0XBL```JX,)_E`("3Y0``6.,I```*`"#9Y0%PH.$]
M4%+B`5"@$P``4N,`4*`#``!5XQ$``!H`0)CE``!4XPP```H(8*#A!2"@X0D0
MH.$$`*#A$/__ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@
MX?"'O>@)4*#A`3#UY0``4^,]`%,3^___&@E01>#F___J"&!&X`%0A>)&8:#A
M!4"$X`0`H.$`8(?E\(>]Z`E`H.'M___J"$"@X>O__^H0D`(`@#"?Y3!`+>D,
MT$WB>%"?Y0!`H.$`,)/E!#"-Y0`PH.,-$*#A!`"@X<#__^L``%#C#```"@`0
MG>4`()7E`3&"X`3`D^4``%SC`<&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___
M&NW__^H8,)_E`""3Y00PG>4"(#/@`0``&@S0C>(P@+WH3?[_ZYR"`0`0D`(`
M\$\MZ0%`H.$`,-'E["&?Y0S03>(]`%/C`4"!`@!0H.$$`*#A`""2Y00@C>4`
M(*#C=_[_ZPT0H.$`8*#A!0"@X9;__^L`D%#B/@``"G#^_^L&`%#A-0``*@!P
MG>6@@9_E!W&@X0``U>4](%#B`2"@$P``4.,`(*`#``!2XP4```H%(*#A`3#R
MY0``4^,]`%,3^___&@4@0N`"`(;B`@"`X`!@F.5(_O_K``!0XP<`AN=,```*
M`""8Y0`0G>4%`*#A`3#0Y`$1DN<]`%/C``!3$P`PP>4&```*`2"!X@$PT.0"
M$*#A``!3XST`4Q,!,,+D^?__&@$@H.$],*#C`##!Y0$PU.0``%/C`3#BY?O_
M_QH``*#CY#"?Y0`@D^4$,)WE`B`SX#0``!H,T(WB\(^]Z`&02>(!,-3D``!3
MXP$PZ>7[__\:\?__ZK2`G^4`H)CE`#":Y0``4^,D```*"C"@X00@L^4)$*#A
M``!2XP&0B>+Z__\:`Q"!X@$1H.&$,)_E`""3Y0``4N,/```:`2"@XP$`H.$`
M((/E"_[_ZP"P4.(0```*"7&@X0H0H.$'(*#AP/W_ZP"PB.4!,(GB`""@XP,A
MB^<`D(WEI?__Z@H`H.'?_?_K``!0XP"PH.$)<:`1``"(Y?/__QH``.#CR/__
MZ@.0H.$($*#CW___ZLO]_^N@@@$`$)`"`"B0`@!0,9_E\$$MZ0!`4.)XT$WB
M`#"3Y70PC>4`,*#C`@``"@`PU.4``%/C!@``&B0QG^4`()/E=#"=Y0(@,^!$
M```:>-"-XO"!O>C6_?_K`%!0XO7__PH`<9_E!0"@X2C^_^L``%#C)@``"A,P
MT.43@(#B+@!3XR<```H3,-#E+@!3XRH```H$`*#AWOW_ZP!@H.$(`*#AV_W_
MZP``AN`"`(#BQOW_ZP<PH.$`(.#C`1"@XQ`!C>@`8*#AX?W_ZP80H.$(((WB
M`P"@XQ;^_^L!`'#C!@"@X0,```H8,)WE#SH#X@$)4^,8```*D_W_ZP8`H.%P
M_?_K!0"@X0'^_^L``%#CV/__&@4`H.$5_O_K!`"@X73]_^O$___J`3#8Y0``
M4^/,__\*$S#0Y2X`4^/4__\:`3#8Y2X`4^/1__\:`C#8Y0``4^/#__\*S?__
MZJO__^OE___J<OW_ZZ2"`0`T10$`$$`MZ7#03>)T,)_E`!"@X0!`H.$-(*#A
M`P"@XP`PD^5L,(WE`#"@X_+]_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!
M"5,3!@``"C`PG^4`()/E;#"=Y0(@,^`'```:<-"-XA"`O>@$`*#A`A"@X[_]
M_^L0#V_AH`*@X?+__^I/_?_KJ((!`/!`+>D!VDWB#-!-XMS`G^4!.HWBV""?
MY0!@H.$!4*#AT`"?Y000C>($,(/B`,"<Y0#`@^4`P*#C4?W_ZP#`4.(A``#:
M"#"-X@%`3.($X(/@I""?Y00P7N4`<)+E``!3XQ<``!H``%3C&0``"@0@H.$O
M$*#C!`"-XIC]_^L``%#C$P``"@<`H.&^_?_K!#"@X00@C>(&$*#AHOW_ZP$Z
MC>)(()_E!#"#X@`0DN4`()/E`1`RX`P``!H!VHWB#-"-XO"`O>@,0*#AY___
MZB@PG^4`<)/E!P"@X:K]_^L%(*#A!A"@X2/]_^OK___J$OW_ZZR"`0#_#P``
M/$4!`!20`@`<,)_E$$`MZ0``D^6=_?_K$$"]Z`PPG^4,()_E#!"?Y5/]_^H4
MD`(`T((!``@5`0!,10$`$$`MZ0C03>(T0)_E``"4Y8_]_^OL___K``"4Y8S]
M_^L@,)_E`""@XP0@C>48$)_E&""?Y0`PC>58_?_K"-"-XA"`O>@4D`(`*$@!
M`&A%`0"0+P$`,$`MZ0+:3>(<T$WBJ""?Y0(ZC>(4,(/B`""2Y0`@@^4`(*#C
M%?W_ZY`PG^60()_E`1"@XPD`C>B(,)_E#`"-XB/]_^L!&HWB#`"-XA`0@>(!
M*J#CZ/S_ZP!`4.(`4*"S"0``N@$`A.+X_/_K`%!0X@4```H!&HWB$!"!X@0@
MH.&V_/_K`#"@XP0PQ><".HWB)""?Y10P@^(`$)+E`""3Y0$0,N`#```:!0"@
MX0+:C>(<T(WB,("]Z+W\_^NP@@$`C$4!``$0``"`10$`R___ZO!/+>E"W4WB
M!-!-XO0AG^5!/8WB`%"@X0%@H.'H`9_E$!"-XCPP@^(`()+E`""#Y0`@H.,&
M_O_K+Q"@XP!`H.$%`*#AY?S_ZP``4.,-```*N`&?Y040H.%5_O_K!0"@X4$]
MC>*<(9_E/#"#X@`0DN4`()/E`1`RX&$``!I"W8WB!-"-XO"/O>@%`*#AS?S_
MZWP1G^4`@*#A!@"@X?_\_^L`H%#BZ?__"@`PVN5DD9_E7'&?Y0``4^-\8(WB
M.0``"@``5.,$```*"A"@X00`H.%9_/_K``!0XRD```H*`*#AN/S_ZP$00.(!
M,(K@`2#:YP#@H.$O`%+C"@``&@(`0.(``(K@`P!`X`,00>`#(*#A`+"@XP'@
M@^``L,/F`<!RY2\`7./Z__\*`3"(X@[@@^`!"E[CQ?__JMPPG^4!*J#C`1"@
MXP0PC>4&`*#A"3"@X0A0C>4`H(WEJ?S_ZQ`@C>(&$*#A`P"@X][\_^L``%#C
M`P``&B`PG>4/.@/B`@E3XQ0```H'$*#A``"@X\/\_^L``%#C`*"@X:S__PH`
M,-KE``!3X\7__QH``%3C`@``"@`PU.4N`%/C`@``"ER@G^4!X*#CU___Z@$P
MU.4``%/CZ___"OC__^H!$*#C!@"@X:O\_^L``%#CY?__&@80H.$8`)_E[OW_
MZP8`H.$U_/_KEO__ZC;\_^NT@@$`D$4!`)Q%`0"L10$`L$4!`+A%`0``10$`
M`##0Y0``4^,>_R\!`2"`XB\`4^,"`*`!`3#2Y```4^/Z__\:'O\OX1!`+>D`
M0%#B+```"@`PU.4``%/C*0``"E?\_^L!`$#B`#"$X`,`5.$#(*`Q`P``.B4`
M`.H$`%+A`C"@X2(```H",*#A`1!2Y"\`4>/X__\*`P!4X1P``"H!,$/B`P!4
MX1L```H`(-/E+P!2X_G__QH!,$/B`P``Z@`0T^4!,$/B+P!1XP(``!H#`%3A
M`R"@X?C__SH$($+@`C""X@$*4^,1``"*`2""X@00H.$!.J#C/`"?Y?'[_^LT
M`)_E$("]Z!!`O>@L`)_E[_O_Z@,`5.'F__\:`##3Y2\`4^/W__\*$$"]Z!``
MG^7G^__J``"@XQ"`O>@\D`(``$4!`+A%`0`$X"WE--!-XD#AG^5`,9_E","-
MX@`PD^4L,(WE`#"@XP\`ON@/`*SH#P"^Z`#@GN4/`*SH'`&?Y;#@S.%E_?_K
M%`&?Y6/]_^L0`9_E8?W_ZPP!G^5?_?_K"`&?Y5W]_^L$`9_E6_W_ZP`!G^59
M_?_K_`"?Y5?]_^OX`)_E5?W_Z_0`G^53_?_K\`"?Y5']_^L$$(WBZ`"?Y1K]
M_^L`$%#B`0``"LP`G^5N_?_K!!"-XM``G^43_?_K`!!0X@$```K$`)_E9_W_
MZP00C>*\`)_E#/W_ZP`04.(+```*C`"?Y6#]_^NH$)_E>`"?Y5W]_^M<,)_E
M`""3Y2PPG>4"(#/@$0``&C30C>($\)WD!!"-XH``G^7[_/_K`!!0X@(```I,
M`)_E3_W_Z^W__^IH$)_E"B"@XQD`C>(:_/_K``!0X^?__QHC$(WB]/__ZI'[
M_^O<@@$`N((!`+Q%`0#(10$`T$4!`-Q%`0#D10$`]$4!`)!%`0``1@$`#$8!
M`!A&`0"<10$`)$8!`#A&`0`$10$`3$8!`'Q&`0!<1@$`<$8!`!!`+>D(T$WB
M:$"?Y6@PG^4``)3E`#"3Y00PC>4`,*#C`0!PXP8```I,,)_E`""3Y00PG>4"
M(#/@#0``&@C0C>(0@+WH-`"?Y0T0H.'%_/_K``!0XP0```H``-#E,`!0XP``
M4!,!`*`3``"@`P``A.7L___J7_O_ZPB0`@"\@@$``$8!`!!`+>DY^__K,OO_
MZP``4.,``)`5$("]Z'!`+>D8T$WBL#"?Y0!0H.$0$(WBJ`"?Y0`PD^44,(WE
M`#"@XZC\_^L%$*#A`$!0X@(```H`,-3E``!3XP@``!I\`)_E^/S_ZW`PG^4`
M()/E%#"=Y0(@,^`7```:&-"-XG"`O>@/^__K``!0X_7__QH%`*#A<?O_ZP!@
MH.$$`*#A;OO_ZP``AN`"`(#B6?O_ZS`PG^4!$*#C"$"-Y00PC>4`(.#C(#"?
MY0!0C>4`0*#A<?O_ZP00H.'@___J)OO_Z\""`0"`1@$`K$4!`+!%`0!P-I_E
M\$\MZ0!PH.$"V4WB!P"3Z/S03>*$P(WB#$"#X@<`C.@DP(/B#P"TZ`)9C>)$
M9I_EG."-X@!@EN7T8(7E`&"@XP\`KNCT4(7B`P"4Z)!0C>(#`([H!P"<Z`<`
MA>@8$(WB%`:?Y6/\_^L`0%#B`@``"@`PU.4``%/C``$`&J3__^L`4%#BV0``
M"@4`H.$V^__K@`"@X0$`@.(A^__K`"#5Y0``4N,`8*#A"P``"LR%G^4&0*#A
M!`"@X0`@C>4(,*#A`"#@XP$0H.,V^__K`2#UY0)`A.(``%+C]?__&J`%G^6@
M4(WB`@``Z@0`E>0``%#C#0``"A@0C>(^_/_K`$!0XOC__PH`,-3E``!3X_7_
M_PIK_?_K``!0X_+__PH$`*#AU?K_ZP!`4.(4```:`%"@XX20C>+X,(WB!3&#
MX'1`$^4``%3C#```"@&`A>((@8G@`##4Y0``4^,'```*!`"@X5?]_^L!4(7B
M``!0XSH``!H$0)CD``!4X_3__QH`0*#C!`"@X?CZ_^OXE)_E`*"@X08`H.'T
M^O_K``"*X`&K@.($H(KB"@"@X=WZ_^O8-)_E`"#@XP$0H.,(,(WE#&"-Y<@T
MG^4`0(WE!)"-Y0"`H.'T^O_K"`"@X0<=H./Z^O_K`0!PXP,``!KK^O_K`#"0
MY1$`4^.7```:&""-X@@0H.$#`*#C+/O_ZP!04.(7```*?"2?Y0"`C>4!$*#C
M``"2Y0`PE^5L))_E^?K_ZP!@H.,".8WB/"2?Y?0P@^(`$)+E`""3Y0$0,N`(
M`0`:!@"@X0+9C>+\T(WB\(^]Z`0`H.&%^O_K`$!0XK'__PK#___J*#"=Y0\Z
M`^(!"5/CX___&C!`G>5>^O_K``!4X=___QHH,)WE@SN@X:,[H.$'#5/CVO__
M&@H`H.&=^O_K&!"-X@!@H.'@`Y_ESOO_ZP``4.-Y```*`$"7Y6OZ_^L`$*#A
M!`"@X;+]_^L`H%#B<@``"@H`H.&@^O_K`P!0XP!`H.$+``":!`!`XJ`3G^4`
M`(K@-OK_ZP``4.,%```:!`!4XZ@```H$0(K@!3!4Y2\`4^.D```*V?[_ZP`0
M4.(#```:"@"@X7?Z_^L`0%#B7```&EP3G^5<`Y_E`OS_ZX#Z_^M4<Y_E5#.?
MY0`@X.,!$*#C\(#-X0QPC>5$HY_E"`"-Y08`H.&+^O_K#@``ZH;Z_^L`,)#E
M$0!3XQ```!IP^O_K`5"%X@0@H.$*,*#A`1"@XPQ0C>40<(WE\(#-X0@`C>4&
M`*#A>_K_ZP<=H.,&`*#A@?K_ZP$`<.,`0*#AZO__"@@`H.$0^O_K!A"@X9@"
MG^7<^__K!@"@X<_^_^N/___J!8"@X9!@C>+X,(WB"#&#X&@`$^4``%#C(0``
M"@%`B.($48;@&!"-XG;[_^L$@*#A`#!0X@(```H`,-/E``!3XP0``!H$`)7D
M``!0XQ0```H!0(3B\O__Z@OZ_^L`4%#BZ/__"@O__^HT(I_E!#"-Y0"`C>4!
M$*#C``"2Y0`PE^5`(I_E9OK_ZP!@H.-K___JJ?[_ZP0`H.'[^?_K`&"@X6;_
M_^H-`*#C(?K_ZQA2G^53(*#C`&"@X?_^_^H`H)?EBO__Z@)0H.,`,.#C$2#@
MXP!0C>4*^O_K]!"-X@8@H.,$`*#AQ_G_Z_0PW>4``%/C`@``&O4PW>5#`%/C
M/P``"@`PH.,`(*#C`#"-Y00`H.$`,*#C^OG_Z^,$`.L`4*#A`@``ZO00C>(%
M`*#A`04`ZP(IH./T$(WB!`"@X;'Y_^L`(%#B]O__R@0`H.%;^O_K!1"@X;0`
MC>)&!0#KR*"-XO@PC>(DL9_E"E"@X45`0^(Q<$/B`1#TY04`H.$+,*#A`!"-
MY0`@X.,!$*#C"?K_ZP0`5^$"4(7B]?__&A@QG^4``*#C##"-Y?``S>4<,9_E
M`"#@XP$0H.,&`*#A``>-Z/SY_^N%___J!$"7Y0``5.-7__\*!`"@X>?Y_^L#
M`%#C4___F@0`0.+D$)_E``"$X'[Y_^L``%#C!*"@`4S__^KV,-WE00!3X[S_
M_QKW,-WE0P!3X[G__QKX,-WE2`!3X[;__QKY,-WE10!3X[/__QH`,.#C.2#@
MXP0`H.$`4(WEK_G_Z_00C>($`*#A*2"@XVSY_^M@,)_E]""-X@@@C>4,,(WE
M`"#@XV`PG^4!$*#C!@"@X?"`S>'.^?_K5___ZH3Y_^L`@P$`Q((!`)!%`0"8
M1@$`!$4!`+A%`0"L1@$`H$8!`""0`@#P1@$`1$<!`$Q'`0!\1@$``$8!`"A(
M`0!L1P$`?$<!`+1&`0"01@$`7$<!`%1'`0#P3RWI#-!-XBQ3G^4L,Y_E``"5
MY0`PD^4$,(WE`#"@X_GY_^L`0*#A``"5Y?;Y_^MH(-3E#1"@X0`PH.$``Y_E
M:2##Y;GZ_^L``%#C`@``"@`PT.4Q`%/CGP``"G']_^L``)7EZ/G_Z]@2G^4+
M,*#C`2"@XW[Y_^L``%#C+P``"L1RG^40$)#E`*"5Y00@E^48D)'E`0!2XRH`
M`-H`0*#C"0``ZA`0DN4(`*#A&?G_ZP0@E^4``%#C;P``&@)`A.("`%3A!D"@
MX6L``*H*`*#AS?G_ZP`PH.,$(*#A"1"@X:CY_^L`L%#B80``"@`@F^4($)?E
M`6"$X@@PDN4&@9'G_S3#X]\XP^/[/,/C_S##XP$+4^,`H)7EX?__"@H`H.&Y
M^?_K`!";Y0(PH.,`(*#C-_G_ZP"@E>4`$*#AV?__Z@"@E>4`<I_E"@"@X:[Y
M_^OX$9_E`S"@XP$@H.-$^?_K`$!0X@H```H``)7EIOG_ZQ`PE.78(9_E`!"3
MY1[Y_^L0,)3E`#"3Y0@PD^4!!1/C7```&@``E>6;^?_KM!&?Y0,PH.,!(*#C
M,?G_ZP!`4.(*```*H`&?Y0T0H.%;^O_K`&!0X@``E>5'```*COG_ZQ`PE.4&
M(*#A`!"3Y0;Y_^L``)7EB/G_ZP!`H.$``)7EA?G_ZV01G^4!(*#C,?G_ZUPA
MG^4`$*#A!`"@X?KX_^L``)7E?/G_ZP`PH.,-$*#A:3#`Y3P!G^5`^O_K``!0
MXP!`H.$,`(?E'P``"@<=H.,$`*#A+OG_ZP$P@.(1`%#C`0!3$S(``(K@,)_E
M`""3Y00PG>4"(#/@+```&@S0C>+PC[WH!""7Y0"@E>4!$$+B!`!1X:___QH!
M`%+CK?__V@%`H.,*`*#A6_G_ZPD0H.&N^/_K!#"7Y0%`A.($`%/A`*"5Y?;_
M_\JB___J"`"7Y9O]_^L``%#C`$"@X0P`A^79__\:D`"?Y0/Y_^L!,-#E``!3
MXUW__PI;___J1OG_ZQ`@E.4(,)?E``"2Y0`0D^5?^__KM?__Z@``E>4^^?_K
M$#"4Y0`0D^4%^?_KG/__ZJ;X_^L($)?E`#"@X00@H.$`$)'E-`"?Y>OX_^L4
MD`(`R((!`.1%`0"01P$`*)`"`)A'`0"<1P$`P$<!`)Q%`0"D1P$`O$<!`)!%
M`0#$1P$`Z$<!`'!`+>D`4*#A:?S_ZP`PT.4`0*#A``!3XP4```H!((#B+P!3
MXP)`H`$!,-+D``!3X_K__QH&_?_K``!5XP``4!-P@+T(`##5Y0``4^-P@+T(
M'!"?Y00`H.$$(*#C_OC_ZP``4.-P@+T8!0"@X7!`O>BL^O_JK$8!``````#(
M/9_E\$\MZ:7?3>)`$(#B@%"`X@@@C>(`0*#C`#"3Y8PRC>4`,*#C!,`1Y0C@
M$>4($('B+#2@X?\\`^(L/(/A#&2@X0P\@^'_R`;B##"#X04`4>$^S[_F!$""
MY0Q`@N4(,(+E`,""Y1`@@N+M__\:`NR-X@T0H.$`0*#C`<"@X0A@L>5(4)SE
M<#"<Y1B`G.5T()SE3'"<Y04P(^`<4)SE"#`CX`3`D>4'("+@!C`CX`4@(N`,
M("+@H\^@X8+`C.&#,(SA#@!1X81`@>6`,('EZ?__&@B@D.4,X)#E`)"0Y2K!
MH.$.SXSA$("0Y0I?C.$$()#E&,"0Y=0\G^4($)WE#&`HX*GMH.$@P)#E`Q"1
MX(+BCN$,0)'@B<*.X03`G.`80)#E"F`&X`1@)N`0$)WE*4&@X07@*.`"3X3A
M&""0Y0;`G.`)X`[@`Q"1X`E/A.$(X"[@`A"1X!@@G>7L;:#A#A"1X`3@)>`&
M$)'@#.`.X`,@DN!LP:#A!>`NX"!PG>4(()+@X6V@X0X@DN`,X"3@!B"2X`'@
M#N`#<)?@81&@X03@+N`HL)WE!7"7X`Y0E^#B;:#A`>`LX`90E>`"X`[@`[";
MX&(AH.$,X"[@,'"=Y01`F^#E;:#A#D"4X`+@(>`&0)3@!>`.X`-PE^!E4:#A
M#,"7X`'@+N`X<)WEY&V@X0[@G.`%P"+@!N">X`3`#.`#<)?@9$&@X0$0E^`"
MP"S@0'"=Y>YMH.$,P)'@!!`EX`;`G.`.$`'@`W"7X&[AH.$"()?@!1`AX$AP
MG>7L;:#A`1"2X`X@).`&$)'@#"`"X`-PE^!LP:#A!"`BX`50E^!0<)WEX6V@
MX0)0E>`,("[@!E"5X`$@`N`#<)?@81&@X0X@(N`$0)?@6'"=Y>5MH.$"0)3@
M`2`LX`9`E.`%(`+@`W"7X&51H.$,("+@#N"7X&!PG>7D;:#A`N">X`4@(>`&
MX)[@!"`"X`-PE^!D0:#A`2`BX`S`E^!H<)WE[FV@X0+`G.`$("7@!L"<X`X@
M`N`#<)?@;N&@X04@(N`!$)?@<'"=Y>QMH.$"$)'@#B`DX`80D>`,(`+@`W"7
MX&S!H.$$("+@!5"7X'APG>7A;:#A`E"5X`P@+N`&4)7@`2`"X`-PE^!A$:#A
M#B`BX`1`E^"`<)WEY6V@X0)`E.`!("S@!D"4X`4@`N`#<)?@95&@X0[@E^`,
M("+@B'"=Y>1MH.$"()[@!>`AX`8@DN`$X`[@`W"7X&1!H.$,P)?@`>`NX)!P
MG>7B;:#A#N"<X`3`)>`&X)[@`L`,X`-PE^!B(:#A!<`LX`$0E^"8<)WE[FV@
MX0P0D>`"P"3@!A"1X`[`#.`#<)?@H+"=Y03`+.`%4)?@X6V@X0Q0E>!NP2+@
M!E"5X`'`#.`#,)O@!&"3X`+`+."P.9_EJ$"=Y6$1H.$,P);@Y6V@X0;`G.!N
M82'@`T"4X`5@)N`"()3@L$"=Y08@DN#L?:#A!W"2X&[AH.%E(2'@`T"4X`[@
ME.`,0"+@N""=Y6S!H.$$X)[@YTV@X03@GN!E02S@`R"2X`=`).`!()+@P!"=
MY00@DN#N3:#A!&"2X&51H.%G(2S@`Q"1X`50D>`.$"+@R""=Y6[AH.'F3:#A
M`1"5X`00D>!G02[@`R"2X`9`).`,()+@T,"=Y00@DN#A3:#A!""2X&=QH.%F
M02[@`\"<X`=PG.`!0"3@V,"=Y010E^!A$:#AXGV@X0=0E>!F02'@`\"<X.!P
MG>4"0"3@#N"<X`3@GN#ES:#A#.">X&9!H.$#P)?@8F$AX`3`G.`%0";@Z&"=
MY651H.'N?:#A!,"<X`?`G.!B027@`V"6X`Y`).`!$);@\&"=Y000D>#L3:#A
M!!"1X&(AH.%N027@`V"6X`Q`).`"();@^&"=Y6S!H.$$()+@X4V@X00@DN!N
M<2S@`T"6X`5`E.`!4"?@`'&=Y05`E.#B7:#A!4"4X&%A+.`#<)?@;N&@X0)@
M)N`(49WE#N"7X&(AH.$&X)[@Y&V@X0;@GN!A82+@`U"5X`1@)N`,P)7@$%&=
MY0;`G.#N;:#A!L"<X&$1H.%D82+@`U"5X`Y@)N`8<9WE`1"5X&[AH.'L7:#A
M!A"1X`40D>!D82[@`W"7X`Q@)N`@49WE`B"7X`8@DN#A;:#A!B"2X&1!H.%L
M82[@`U"5X`%@)N`H<9WE!$"5X&$1H.'B7:#A!D"4X`5`E.!L82'@`W"7X`)@
M)N`P49WE#N"7X`;@GN#D;:#A!N">X&S!H.%B82'@`U"5X`1@)N`X<9WE#,"5
MX&1!H.'N7:#A!L"<X`7`G.!B823@`W"7X$!1G>4.8";@`1"7X&[AH.$&$)'@
M[&V@X080D>!B(:#A#F`DX`,PE>!(<9WE#&`FX`(@D^!LP:#AU#:?Y0Q0CN$&
M()+@X6V@X08@DN`,L`[@`V"7X`%0!>`+4(7A81&@X5!QG>4$0);@!4"4X`%@
MC.'B7:#A!4"4X`)@!N`!4`S@`W"7X&(AH.$.<)?@!6"&X5A1G>4"L('AY.V@
MX0=@EN`.8);@!+`+X`)P`>`#X)7@9$&@X0=PB^$,X)[@8+&=Y03`@N$.X)?@
MYGV@X0?@GN`$4`+@`[";X`;`#.!H<9WE9F&@X0$0F^`%P(SA`<"<X`90A.'N
M':#A#K`%X`'`G.`&4`3@`Q"7X&[AH.$%4(OA`A"1X`$0E>`.((;A[%V@X040
MD>`,(`+@#E`&X`4@@N%PL9WE>%&=Y6S!H.$$4(WE`[";X`Q0CN$$0)O@`;`%
MX`10G>4$0)+@X2V@X0)`E.!A$:#A#'`.X`,@E>`'<(OA!B"2X("QG>4!8(SA
M!&`&X`%0#.`"()?@Y'V@X0<@DN`%4(;A`[";X(AAG>4.X)O@!&"-Y0Y0E>#B
M[:#A9$&@X0Y0E>`$X)WE!'"!X0*P!^`$8`'@`^">X&(AH.$&8(OA#,">X)#A
MG>4"L(3A#,"6X.5MH.$&P)S@!;`+X`)@!.`#X)[@!K"+X0$0GN#L;:#A`1";
MX&51H.$&$)'@F&&=Y05P@N$%L`+@#.`'X`-PEN`$0)?@"^".X>%MH.$$X)[@
M!N">X&S!H.&@89WE#$"@X0RPA>$$<`7@`<`+X`-@EN!A$:#A`B"6X`?`C.&H
M<9WE`6"$X0+`G.#N+:#A`L"<X`&P!.`#<)?@#F`&X&XAH.$%4)?@"^"&X;!Q
MG>4"8('A!>">X.Q=H.$%X)[@`K`!X`Q@!N`#<)?@;%&@X01PE^`+P(;AN+&=
MY05`@N'N;:#A!\"<X`;`G.`%<`+@`V";X`Y`!.`'0(3A;N&@X<!QG>4!$);@
M`1"4X`Y@A>'L3:#A!!"1X`Q@!N`.L`7@`W"7X&Q!H.$+L(;A`B"7X,AQG>4$
M8([AX<V@X0(@F^`,()+@!+`.X`-PE^`!8`;@8<&@X0M@AN$%4)?@T+&=Y0P0
MA.$%4);@XFV@X090E>`,<`3@`V";X`(0`>#8L9WE8B&@X0[@EN`'$('A#A"1
MX`)PC.'E[:#A#A"1X`5P!^`"8`S@`^";X&51H.$&8(?A!.">X.!QG>4%0(+A
M#N"6X.%MH.$&X)[@`4`$X`5@`N`#,)?@!D"$X>BQG>4,P)/@5#.?Y>YMH.$,
MP)3@!L"<X&%!)>`#L)O@`K";X`Y`).#P(9WE;N&@X>QMH.$$0)O@!D"4X&%A
M+N`#()+@#&`FX`4@DN#X49WE!B"2X.1MH.$&<)+@81&@X6PA+N`#4)7@`1"5
MX`10(N``(IWE9$&@X040D>#G7:#A!1"1X&Q1).`#()+@!U`EX`X@DN`(XIWE
M!2"2X.%=H.$%L)+@;,&@X6<A).`#X)[@#,">X`'@(N`0(IWE81&@X0[`G.#K
M[:#A#N"<X&=1(>`#P)+@"U`EX`3`G.`80IWE!<"<X.Y=H.$%P)S@9R&@X6M1
M(>`#0)3@#E`EX`)`E.`@(IWE;N&@X>QMH.$%0)3@!D"4X&M1+N`#()+@#%`E
MX`$@DN`H$IWE!2"2X.1MH.$&<)+@:U&@X6PA+N`#$)'@!1"1X`10(N`P(IWE
M9$&@X040D>#G7:#A!1"1X&Q1).`#()+@!U`EX`X@DN`XXIWE!2"2X.%MH.$&
ML)+@;,&@X6<A).`#X)[@#,">X`'@(N!`(IWE81&@X0[`G.#K[:#A#L"<X&?A
M(>`#()+@!$"2X`L@+N!(XIWE`B"4X.Q-H.$$0)+@9V&@X6LA(>`#X)[@!F">
MX`S@(N!0(IWE;,&@X0Y@EN#D[:#A#N"6X&M1+.`#()+@`1"2X`0@)>!84IWE
M[GV@X0(0D>`'$)'@9&$LX&LAH.$#4)7@#F`FX`)0E>!@(IWEX7V@X090E>!N
M8:#A!U"5X&3A)N`#()+@`>`NX`P@DN!HPIWE#B"2X.7MH.$.()+@9$&@X6'A
M)N`#P)S@!>`NX`1`G.!PPIWE95&@X>)]H.$.0)3@!T"4X`;@H.%A<27@`V"<
MX`)P)^!XPIWE#F"6X`=@EN!BX:#AY"V@X0)@EN!A$:#A`R"<X`YP)>`!()+@
M!'`GX(`2G>4'()+@YLV@X0S`DN!D0:#A`S"1X`0@+N`),)/@!B`BX`4PD^`"
M,)/@["V@X0(PD^`8()#E9F&@X0K`G.`(8);@`D"4X"`@D.4`,(#E1#"?Y0`0
MH.,"X)[@","`Y1!@@.480(#E(."`Y000@.4,$(#E%!"`Y1P0@.4D$(#E`""3
MY8PRG>4"(#/@`0``&J7?C>+PC[WH__3_ZS"#`0"9>8):H>O9;MR\&X_6P6+*
M\$<MZ8``H.,>]?_K4%"/XM!`Q>%0<(_BT&#'X5"0C^+0@,GA`""@X_A`P.%(
M4(_BT$#%X?!AP.%$<(_BT&#'X?A!P.$`0*#C`%"@X_"`P.'P8L#A>""`Y?A"
MP.'P0\#A\(>]Z(FKS>\`````_MRZF``````!(T5G`````'94,A``````\.'2
MPP````#X3RWI`I"@X=@BP.$`4*#A`'"@XXD!H.$"8(#@!P!3X08`4@$!0*#A
M,""5Y300E>4)H*#AR;^@X0$``)H!()+B!Q"AX*H^H.%X`)7EBS&#X0(PD^"K
M+J#A`2"BX```4.,X@(7B^&+%X3`PA>4T((7E'P``&C\`6>,N``#:0)!)XBEC
MH.$!<(;B!W.$X$#@A.((,*#A`,"4Y00`E.4($)3E#""4Y1!`A.(.`%3A`,"#
MY00`@^4($(/E#""#Y1`P@^+S__\:!0"@X3#\_^L'`%3A[?__&@9M9N`&DXG@
M!Q"@X0@`H.$)(*#AA_3_ZWB0A>7XC[WH0&!@X@8`6>$)8*"Q``"(X`8@H.$$
M$*#A?O3_ZW@PE>4#,(;@0`!3XW@PA>7XC[T8!0"@X0:02>`&0(3@%OS_Z\[_
M_^H$<*#AYO__ZO!!+>DX<('B`4"@X2@0D>4P8)3E?\#@XZ$QH.$_,`/B`2"#
MXC@`4N,`4*#A,8^_YC9OO^8"`(?@`\#'YSP``-I`(&+B`!"@X\CT_^L$`*#A
M_OO_ZP<`H.$X(*#C`!"@X\+T_^L$`*#A<&"$Y72`A.7V^__K`S#4Y00`H.$`
M,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4X04P
MQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40,)3E(S2@
MX0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XPQ>48,)3E
M#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!O>@?
M]/_J."!BX@`0H..+]/_KQ___ZO!'+>D`<*#A2&"?Y4A0G^4&8(_@!5"/X`5@
M1N`!@*#A`I"@X??S_^M&8;#A\(>]"`!`H.,$,)7D`4"$X@D@H.$($*#A!P"@
MX3/_+^$$`%;A]___&O"'O>@T20$`+$D!`![_+^$(,)_E`S"/X``PD^4<]/_J
M($L!``A`+>D(@+WH`0`"`"]T;7``````+@```%!!4E]435!$25(``%1%35!$
M25(`5$U0`%5315(`````55-%4DY!344`````+BX``"5S+R5S````+W!R;V,O
M<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`4$%27U1%35``````
M4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!0
M15),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10``
M`%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q
M````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P``
M``!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P````!!4D=6`````!@```!P97)L`````%!!4CHZ4&%C:V5R.CI615)324].
M`````#$N,#4P````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I
M;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M
M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE
M.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF
M,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN
M("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&
M2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@
M/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU
M;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@
M)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ
M92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?
M<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D
M;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@
M;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F
M+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T
M.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G
M:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP
M86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E
M<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H
M)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U
M9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U
M-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE
M;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A
M;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H
M(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T
M>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F
M=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#
M(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF
M(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@
M)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@
M)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P
M96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M
M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*
M:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z
M("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A0
M05(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2
M/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN
M960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE
M<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B
M:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<
M15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<
M6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE
M;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J
M;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL
M93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO
M<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E
M;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M
M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F
M:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]
M("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE
M>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX
M7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@
M;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I
M<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG
M97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@
M=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````
M`,2-`@#$C0(`Q(T"`,2-`@#$C0(`Q(T"`,2-`@#$C0(`Q(T"`,2-`@#$C0(`
MQ(T"`,2-`@!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(`````#X1`$``$4!```````$10$`"$4!`!!%`0"410$`&$4!````
M```<10$`)$4!``````#$C0(`G);_?P$`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"\&@$`E!H!````````````````````````````````
M``$````!`````0```,L!```!````&@(```$```!7`P``#````'P4`0`-````
M[$0!`!D```"\C0(`&P````0````:````P(T"`!P````$````]?[_;[0!`0`%
M````%`P!``8```!D!0$`"@```/$$```+````$````!4``````````P```.R.
M`@`"````"`(``!0````1````%P```'02`0`1````/!(!`!(````X````$P``
M``@````>````"````/O__V\!````_O__;]P1`0#___]O`P```/#__V\&$0$`
M````````````````````````````````````````````````````````````
M````W(T"````````````B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4
M`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!
M`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`
MB!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(
M%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4
M`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!
M`(@4`0````````````````#_____-$@!`$=#0SH@*%)A<W!B:6%N(#DN,RXP
M+3$R*W)P:3$I(#DN,RXP`$$N````865A8FD``20````%-@`&!@@!"0$*`A($
M$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR
M96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A=&$N<F5L+G)O
M`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I
M8G5T97,`````````````````````````````````````````````````````
M``````L````!`````@```%0!`0!4`0``&0```````````````0`````````3
M````!P````(```!P`0$`<`$``"0```````````````0`````````)@````<`
M```"````E`$!`)0!```@```````````````$`````````#0```#V__]O`@``
M`+0!`0"T`0``L`,```4`````````!`````0````^````"P````(```!D!0$`
M9`4``+`&```&`````0````0````0````1@````,````"````%`P!`!0,``#Q
M!``````````````!`````````$X```#___]O`@````81`0`&$0``U@````4`
M`````````@````(```!;````_O__;P(```#<$0$`W!$``&`````&`````P``
M``0`````````:@````D````"````/!(!`#P2```X````!0`````````$````
M"````',````)````0@```'02`0!T$@``"`(```4````6````!`````@```!\
M`````0````8```!\%`$`?!0```P```````````````0`````````=P````$`
M```&````B!0!`(@4```@`P`````````````$````!````((````!````!@``
M`*@7`0"H%P``1"T`````````````"`````````"(`````0````8```#L1`$`
M[$0```@```````````````0`````````C@````$````"````]$0!`/1$``!`
M/@`````````````$`````````)8````!``!P@@```#2#`0`T@P``"`````T`
M````````!`````````"A`````0````(````\@P$`/(,```0`````````````
M``0`````````JP````X````#````O(T"`+R-```$```````````````$````
M!````+<````/`````P```,"-`@#`C0``!```````````````!`````0```##
M`````0````,```#$C0(`Q(T``!<```````````````0`````````T`````8`
M```#````W(T"`-R-```0`0``!@`````````$````"````-D````!`````P``
M`.R.`@#LC@``%`$`````````````!`````0```#>`````0````,`````D`(`
M`)```!````````````````0`````````Y`````@````#````$)`"`!"0```L
M$``````````````(`````````.D````!````,``````````0D```)```````
M`````````0````$```#R`````P``<```````````-)```"\`````````````
M``$``````````0````,``````````````&.0```"`0`````````````!````
$````````
